rCTSP: Simulation of Fully Right Skewed CTS Distributions

View source: R/SubTS.R

rCTSPR Documentation

Simulation of Fully Right Skewed CTS Distributions

Description

Simulates from fully right skewed classical tempered stable (CTS) distributions in both the finite and infinite variation cases. When alpha=0 this is the gamma distribution.

Usage

rCTSP(n, alpha, c, ell, epsilon = 0.5, p = 0.5)

Arguments

n

Number of observations.

alpha

Parameter in [0,2).

c

Parameter >0.

ell

Tempering parameter >0.

epsilon

Tuning parameter in (0,1). Only for alpha>=1.

p

Tuning parameter in (0,1). Only for alpha>=1.

Details

Simulates a fully right skewed CTS distribution. The distribution has Laplace transform

L(z) = exp( c int_0^infty (e^(-xz)-1)e^(-x/ell) x^(-1-alpha) dx), z>0

and Levy measure

M(dx) = c e^(-x/ell) x^(-1-alpha) 1(x>0)dx.

Value

Returns a vector of n random numbers.

Author(s)

Michael Grabchak and Lijuan Cao

References

M. Grabchak (2016). Tempered Stable Distributions: Stochastic Models for Multiscale Processes. Springer, Cham.

M. Grabchak (2026). Exact Simulation from Tempered Stable Distributions with Infinite Variation (alpha>=1). <doi 10.48550/arXiv.2604.17732>.

Examples

rCTSP(20, 1.5, 1, 1)

SubTS documentation built on Sept. 14, 2026, 1:06 a.m.