| rCTSM | R Documentation |
Simulates from fully left skewed classical tempered stable (CTS) distributions in both the finite and infinite variation cases. When alpha=0 this is the negative of the gamma distribution.
rCTSM(n, alpha, c, ell, epsilon = 0.5, p = 0.5)
n |
Number of observations. |
alpha |
Parameter in [0,2). |
c |
Parameter >0. |
ell |
Tempering parameter >0. |
epsilon |
Tuning parameter in (0,1). Only for alpha>=1. |
p |
Tuning parameter in (0,1). Only for alpha>=1. |
Simulates from a fully left skewed CTS distribution. The distribution has moment generating function
M(z) = exp( c int_(-infty)^0 (e^(xz)-1)e^(-x/ell) x^(-1-alpha) dx)
and Levy measure
M(dx) = c e^(-|x|/ell) |x|^(-1-alpha) 1(x<0)dx.
Returns a vector of n random numbers.
Michael Grabchak and Lijuan Cao
M. Grabchak (2016). Tempered Stable Distributions: Stochastic Models for Multiscale Processes. Springer, Cham.
M. Grabchak (2026). Exact Simulation from Tempered Stable Distributions with Infinite Variation (alpha>=1). <doi 10.48550/arXiv.2604.17732>.
rCTSM(20, 1.5, 1, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.